@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: uniplate
 version: 1.6.12
-id: uniplate-1.6.12-8f24c9f82f93b9dabcf5d8b53ffd592c
-key: unipl_4To3YAFCK9fCEvWN5uy0eE
+id: uniplate-1.6.12-5a2a0a6de90df137bffce599d35d6149
+key: unipl_IcTSrz3eOLSC4nK8zmJTIn
 license: BSD3
 copyright: Neil Mitchell 2006-2013
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
@@ -58,13 +58,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/uniplate-1.6.12
 library-dirs: /usr/lib/ghc-7.10.3/site-local/uniplate-1.6.12
 data-dir: /usr/share/arm-linux-ghc-7.10.3/uniplate-1.6.12
-hs-libraries: HSuniplate-1.6.12-4To3YAFCK9fCEvWN5uy0eE
+hs-libraries: HSuniplate-1.6.12-IcTSrz3eOLSC4nK8zmJTIn
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
 haddock-interfaces: /usr/share/doc/haskell-uniplate/html/uniplate.haddock
 haddock-html: /usr/share/doc/haskell-uniplate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
